@@ -101,7 +101,7 @@ void MainWindow::createMenu()
     menu->addAction(deleteStationAction);
     menu->addAction(manualAction);
     menu->addAction(renameSetsAction);
-    menu->addAction(restartRadioAction);
+    //menu->addAction(restartRadioAction);
     menu->addAction(changeFontAction);
     menu->addAction(aboutAction);
     menu->addAction(aboutQtAction);
@@ -207,7 +207,7 @@ void MainWindow::deleteStationActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.1.0</h2>"
+                tr("<h2>QRadio 0.1.1</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
