@@ -106,6 +106,7 @@ void Radio::createUI()
     connect(searchRight,SIGNAL(clicked()),SLOT(searchUp()));
 
     stationsBox = new QComboBox;
+	stationsBox->setFixedWidth(100);
     connect(stationsBox, SIGNAL(highlighted(QString)), SLOT(stationPicked(QString)));
     connect(stationsBox, SIGNAL(currentIndexChanged(QString)), SLOT(stationPicked(QString)));
 
@@ -367,7 +368,7 @@ void Radio::changeFont(QFont font, int n)
 
     QFont stationFont(currentFont.toString(), 20);
     stationFont.setUnderline(true);
-    stationFont.setBold(true);
+    //stationFont.setBold(true);
     stationName->setFont(stationFont);
     QFont rdsfont(currentFont.toString(), 14);
 
